%standing_waves
% Illustrations for standing waves on a string.
%
% LAST UPDATED by Andy French May 2017

function standing_waves

%Period /s
T = 2;

%Length of string
L = 1;

%Harmonics
n = [1,2,3];

%Times /s
t = T*linspace(0,1,20);

%Amplitudes
A = 1;

%Number of plot points per surve
N = 1000;

%Fontsize for graphs
fsize = 18;

%%

%Length extent /m
x = linspace(0,L,N).';

%Wavelengths
lambda = 2*L./n;

%Wavenumber
k = 2*pi./lambda;

%Waveshapes
for nn=1:length(n)
    phi(nn).phi = zeros(N,length(t));
    for tt = 1:length(t)
        phi(nn).phi(:,tt) = A*sin(k(nn)*x)*cos( 2*pi*t(tt)/T );
    end
end


%Plot graphs
figure('name','standing waves','color',[1 1 1])
axes; hold on;
xx = repmat(x,[1,length(t)] );
set(gca,'fontsize',fsize)
grid on;
box on;
for nn=1:nn
    plot( xx, phi(nn).phi);
    xlabel( 'Distance x /m','fontsize', fsize )
    ylabel( 'Wave amplitude','fontsize',fsize )
    title( ['Standing wave: Harmonic number=',num2str(nn-1)],'fontsize',fsize )
    print( gcf,['standing wave n = ',num2str(nn),'.png'],'-dpng','-r300' );
    cla;
end
close(gcf);

%End of code